@@ -2,12 +2,12 @@ package DateTimeX::Format::Excel::Types;
 BEGIN {
   $DateTimeX::Format::Excel::Types::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv("v0.10.2");
+use version; our $VERSION = qv("v0.12.2");
 use	5.010;
 use strict;
 use warnings;
 use Type::Utils -all;
-use Type::Library
+use Type::Library 0.046
 	-base,
 	-declare => qw(
 		DateTimeHash
